#
# Cookbook Name:: gitlab_omnibus
# Recipe:: default
#
# Copyright (c) 2015 Drew Blessing, All Rights Reserved.

if node['gitlab_omnibus']['use_packagecloud']
  case node['gitlab_omnibus']['edition']
  when 'community'
    packagecloud_repo 'gitlab/gitlab-ce'
    node.default['gitlab_omnibus']['package_name'] = 'gitlab-ce'
  when 'enterprise'
    packagecloud_repo 'gitlab/gitlab-ee'
    node.default['gitlab_omnibus']['package_name'] = 'gitlab-ee'
  end
end

# gitlab_omnibus_package 'gitlab' do
package node['gitlab_omnibus']['package_name'] do
  action node['gitlab_omnibus']['action']
  version node['gitlab_omnibus']['version']
  notifies :reconfigure, 'gitlab_omnibus_service[gitlab]'
end

template '/etc/gitlab/gitlab.rb' do
  source 'gitlab.rb.erb'
  mode '0640'
  # Must reconfigure immediately on first install otherwise service will fail to start
  notifies :reconfigure, 'gitlab_omnibus_service[gitlab]', :immediately
end

gitlab_omnibus_service 'gitlab' do
  start_command '/opt/gitlab/bin/gitlab-ctl start'
  stop_command '/opt/gitlab/bin/gitlab-ctl stop'
  status_command '/opt/gitlab/bin/gitlab-ctl status'
  restart_command '/opt/gitlab/bin/gitlab-ctl restart'
  reconfigure_command '/opt/gitlab/bin/gitlab-ctl reconfigure'
  action :start
  supports restart: true, status: true
end

if node['gitlab_omnibus']['backup']['enable']
  include_recipe 'gitlab_omnibus::_backup'
end

# If ci_external_url isn't set, CI isn't installed
if node['gitlab_omnibus']['ci_external_url'] && node['gitlab_omnibus']['ci_backup']['enable']
  include_recipe 'gitlab_omnibus::_ci_backup'
end
